@@ -118,6 +118,30 @@ def call(obj, method, *args, **kwargs):
     return function_or_dict_or_member[args[0]]
 
 
+@register.assignment_tag
+def concatenate(*args, **kwargs):
+    """
+    Concatenates the given strings.
+
+    Usage::
+
+        {% load libs_tags %}
+        {% concatenate "foo" "bar" as new_string %}
+        {% concatenate "foo" "bar" divider="_" as another_string %}
+
+    The above would result in the strings "foobar" and "foo_bar".
+
+    """
+    divider = kwargs.get('divider', '')
+    result = ''
+    for arg in args:
+        if result == '':
+            result += arg
+        else:
+            result += '{0}{1}'.format(divider, arg)
+    return result
+
+
 @register.assignment_tag
 def get_form_field_type(field):
     """
@@ -174,7 +198,7 @@ def get_profile_for(user):
 
 
 @register.assignment_tag
-def get_query_params(request, param_name, param_value):
+def get_query_params(request, *args):
     """
     Allows to change one of the URL get parameter while keeping all the others.
 
@@ -184,6 +208,10 @@ def get_query_params(request, param_name, param_value):
       {% get_query_params request "page" page_obj.next_page_number as query %}
       <a href="?{{ query }}">Next</a>
 
+    You can also pass in several pairs of keys and values::
+
+      {% get_query_params request "page" 1 "foobar" 2 as query %}
+
     You often need this when you have a paginated set of objects with filters.
 
     Your url would look something like ``/?region=1&gender=m``. Your paginator
@@ -191,14 +219,18 @@ def get_query_params(request, param_name, param_value):
     filter values when switching pages.
 
     :param request: The request instance.
-    :param param_name: The name of the parameter that should be added or
-      updated.
-    :param param_value: The value of the parameter that should be added or
-      updated.
-
+    :param *args: Make sure to always pass in paris of args. One is the key,
+      one is the value.
     """
     query = request.GET.copy()
-    query[param_name] = param_value
+    index = 1
+    key = ''
+    for arg in args:
+        if index % 2 != 0:
+            key = arg
+        else:
+            query[key] = arg
+        index += 1
     return query.urlencode()
 
 
@@ -338,7 +370,7 @@ def get_range_around(range_value, current_item, padding):
             'right_padding': False,
         }
     if current_item <= left_bound:
-        range_items = range(current_item, range_value+1)[:total_items]
+        range_items = range(1, range_value+1)[:total_items]
         return {
             'range_items': range_items,
             'left_padding': range_items[0] > 1,
@@ -346,7 +378,7 @@ def get_range_around(range_value, current_item, padding):
         }
 
     if current_item >= right_bound:
-        range_items = range(1, current_item+1)[-total_items:]
+        range_items = range(1, range_value+1)[-total_items:]
         return {
             'range_items': range_items,
             'left_padding': range_items[0] > 1,
